@@ -53,7 +53,7 @@ sub read_file {
     my $path = File::Spec->canonpath( $file );
     # warn "Checking for '$root' in '$path'\n";
     ( $path =~ /\A\Q$root\E(\/|(?<=\/))(?!\.\.)/ )
-      or $self->croak_msg("Not in required base path '$root'");
+      or $self->croak_msg("Text::MicroMason::TemplateDir: Template not in required base path '$root'");
   }
   
   return $self->NEXT('read_file', $file );
@@ -106,7 +106,11 @@ Base directory from which to find templates.
 
 =item strict_root
 
-Optional directory beyond which not to read files. If set to 1, uses template_root, Causes read_file to croak if any filename outside of the root is provided. (Note that this is not a chroot jail and only affects attempts to load a file as a template; for greater security see the chroot() builtin and L<Text::MicroMason::Safe>.)
+Optional directory beyond which not to read files. If set to 1, uses
+template_root, Causes read_file to croak if any filename outside of the
+root is provided. (Note that this is not a chroot jail and only affects
+attempts to load a file as a template; for greater security see the
+chroot() builtin and L<Text::MicroMason::Safe>.)
 
 =back
 
@@ -124,6 +128,23 @@ Intercepts file access to check for strict_root.
 
 =back
 
+=head2 EXCEPTIONS
+
+The following additional exceptions are generated by
+Text::MicroMason::TemplateDir when appropriate:
+
+=over 4
+
+=item *
+
+Text::MicroMason::TemplatePath: Template not in required base path '%s'
+
+The template found in the configured template path was not within the
+configured strict_root directory. This may be caused by requesting an
+absolute template filename not within strict_root, or by specifying a
+strict_root which does not match the configured template path.
+
+=back
 
 =head1 SEE ALSO
 
